Index: ios/chrome/browser/ui/toolbar/toolbar_tools_menu_button.h |
diff --git a/ios/chrome/browser/ui/toolbar/toolbar_tools_menu_button.h b/ios/chrome/browser/ui/toolbar/toolbar_tools_menu_button.h |
index 6a88fdb779686bf7f9e4485862032b3c975c78fe..12e5a8d2debd29b086dc7b8a9f9c1dbd9baeb8e0 100644 |
--- a/ios/chrome/browser/ui/toolbar/toolbar_tools_menu_button.h |
+++ b/ios/chrome/browser/ui/toolbar/toolbar_tools_menu_button.h |
@@ -7,14 +7,14 @@ |
#import <UIKit/UIKit.h> |
-#import "ios/chrome/browser/ui/fancy_ui/tinted_button.h" |
+#import "ios/chrome/browser/ui/fancy_ui/colored_button.h" |
#import "ios/chrome/browser/ui/toolbar/toolbar_controller.h" |
// TintedButton specialization that updates the tint color when the tools menu |
// is visible or when the reading list associated with |readingListModel| |
// contains unread items. |
// Draws and animates the icon of the button using UIBezierPaths. |
-@interface ToolbarToolsMenuButton : TintedButton |
+@interface ToolbarToolsMenuButton : ColoredButton |
// Initializes and returns a newly allocated TintedButton with the specified |
// |frame| and the |style| of the toolbar it belongs to. |
@@ -7,14 +7,14 @@ |
#import "ios/chrome/browser/ui/toolbar/toolbar_controller.h" |
-// TintedButton specialization that updates the tint color when the tools menu |
+// ColoredButton specialization that updates the tint color when the tools menu |
// is visible or when the reading list associated with |readingListModel| |
// contains unread items. |